@@ -11,7 +11,8 @@ Rset = list("fancyvrb" = "true", "escapechar" = "`",
         "language" = "R", "basicstyle" = "{\\color{Rcolor}\\small}",
         "keywordstyle" = "{\\bf\\color{Rcolor}}",
         "commentstyle" = "{\\color{Rcommentcolor}\\ttfamily\\itshape}",
-        "literate" = paste("{<-}{{$\\leftarrow$}}2",
+        "literate" = paste("{\"}{\\texttt{\"}}1",
+                           "{<-}{{$\\leftarrow$}}2",
                            "{<<-}{{$\\twoheadleftarrow$}}2",#"%\n",
                            "{~}{{$\\sim$}}1", "{<=}{{$\\leq$}}2",#"%\n",
                            "{>=}{{$\\geq$}}2", "{^}{{$\\scriptstyle\\wedge$}}1", sep=""),
